Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(263)

Unified Diff: net/quic/quic_connection.h

Issue 11377096: Change from re-transmitting an packet with a retransmit number to sending a new packet with a new s… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/congestion_control/send_algorithm_interface.h ('k') | net/quic/quic_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_connection.h
diff --git a/net/quic/quic_connection.h b/net/quic/quic_connection.h
index 51604db7880012c4dcedb01e0c6f35ce81aabe1b..5a13a61bd7f3676515153152933ddc3c8e5b805d 100644
--- a/net/quic/quic_connection.h
+++ b/net/quic/quic_connection.h
@@ -186,14 +186,16 @@ class NET_EXPORT_PRIVATE QuicConnection : public QuicFramerVisitorInterface {
bool ShouldSimulateLostPacket();
protected:
// Send a packet to the peer. If resend is true, this packet contains data,
// and will be resent if we don't get an ack. If force is true, then the
// packet will be sent immediately and the send scheduler will not be
// consulted.
virtual bool SendPacket(QuicPacketSequenceNumber number,
QuicPacket* packet,
- bool resend,
- bool force);
+ bool should_resend,
+ bool force,
+ bool is_retransmit);
// Make sure an ack we got from our peer is sane.
bool ValidateAckFrame(const QuicAckFrame& incoming_ack);
@@ -260,13 +262,16 @@ class NET_EXPORT_PRIVATE QuicConnection : public QuicFramerVisitorInterface {
QuicPacketSequenceNumber sequence_number;
QuicPacket* packet;
bool resend;
+ bool retransmit;
QueuedPacket(QuicPacketSequenceNumber sequence_number,
QuicPacket* packet,
- bool resend) {
+ bool resend,
+ bool retransmit) {
this->sequence_number = sequence_number;
this->packet = packet;
this->resend = resend;
+ this->retransmit = retransmit;
}
};
typedef std::list<QueuedPacket> QueuedPacketList;
@@ -186,14 +186,16 @@ class NET_EXPORT_PRIVATE QuicConnection : public QuicFramerVisitorInterface {
bool ShouldSimulateLostPacket();
protected:
- // Send a packet to the peer. If resend is true, this packet contains data,
- // and will be resent if we don't get an ack. If force is true, then the
- // packet will be sent immediately and the send scheduler will not be
- // consulted.
+ // Send a packet to the peer. If should_resend is true, this packet contains
+ // data, and contents will be resent with a new sequence number if we don't
+ // get an ack. If force is true, then the packet will be sent immediately and
+ // the send scheduler will not be consulted. If is_retransmit is true, this
+ // packet is being retransmitted with a new sequence number.
virtual bool SendPacket(QuicPacketSequenceNumber number,
QuicPacket* packet,
« no previous file with comments | « net/quic/congestion_control/send_algorithm_interface.h ('k') | net/quic/quic_connection.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698